from .. import Provider as BaseProvider


# China jobs from
# https://js.51jobcdn.com/in/js/2016/layer/funtype_array_c.js?20180611
class Provider(BaseProvider):
    jobs = [
        "计算机硬件",
        "高级硬件工程师",
        "硬件工程师",
        "其他",
        "计算机软件",
        "高级软件工程师",
        "软件工程师",
        "软件UI设计师/工程师",
        "算法工程师",
        "仿真应用工程师",
        "ERP实施顾问",
        "ERP技术开发",
        "需求工程师",
        "系统集成工程师",
        "系统分析员",
        "系统工程师",
        "系统架构设计师",
        "数据库工程师/管理员",
        "计算机辅助设计工程师",
        "其他",
        "互联网/电子商务/网游",
        "互联网软件开发工程师",
        "语音/视频/图形开发工程师",
        "多媒体/游戏开发工程师",
        "手机应用开发工程师",
        "网站运营总监",
        "网站运营经理/主管",
        "网站运营专员",
        "产品总监",
        "产品经理/主管",
        "产品专员",
        "SEO/SEM",
        "网络推广总监",
        "网络推广经理/主管",
        "网络推广专员",
        "新媒体运营",
        "电子商务总监",
        "电子商务经理/主管",
        "电子商务专员",
        "网络工程师",
        "UI设计师/顾问",
        "用户体验（UE/UX）设计师",
        "大数据开发/分析",
        "Web前端开发",
        "网站架构设计师",
        "网站维护工程师",
        "系统管理员/网络管理员",
        "网站策划",
        "网站编辑",
        "网页设计/制作/美工",
        "脚本开发工程师",
        "游戏策划师",
        "游戏界面设计师",
        "Flash设计/开发",
        "特效设计师",
        "视觉设计师",
        "音效设计师",
        "网络信息安全工程师",
        "其他",
        "IT-管理",
        "首席技术执行官CTO/首席信息官CIO",
        "技术总监/经理",
        "信息技术经理/主管",
        "信息技术专员",
        "项目总监",
        "项目经理",
        "项目主管",
        "项目执行/协调人员",
        "其他",
        "IT-品管、技术支持及其它",
        "技术支持/维护经理",
        "技术支持/维护工程师",
        "网络管理(Helpdesk)",
        "网络维修",
        "计量工程师",
        "标准化工程师",
        "品质经理",
        "系统测试",
        "软件测试",
        "硬件测试",
        "测试员",
        "文档工程师",
        "配置管理工程师",
        "技术文员/助理",
        "手机维修",
        "电脑维修",
        "其他",
        "通信技术开发及应用",
        "通信技术工程师",
        "有线传输工程师",
        "无线通信工程师",
        "电信交换工程师",
        "数据通信工程师",
        "移动通信工程师",
        "电信网络工程师",
        "通信电源工程师",
        "增值产品开发工程师",
        "手机软件开发工程师",
        "其他",
        "电子/电器/半导体/仪器仪表",
        "集成电路IC设计/应用工程师",
        "IC验证工程师",
        "电子工程师/技术员",
        "电子技术研发工程师",
        "射频工程师",
        "电子/电器维修工程师/技师",
        "变压器与磁电工程师",
        "版图设计工程师",
        "电气工程师/技术员",
        "电路工程师/技术员(模拟/数字)",
        "电声/音响工程师/技术员",
        "激光/光电子技术",
        "半导体技术",
        "自动控制工程师/技术员",
        "电子软件开发(ARM/MCU...)",
        "嵌入式软件开发(Linux/单片机/PLC/DSP…)",
        "嵌入式硬件开发(主板机…)",
        "电池/电源开发",
        "FAE 现场应用工程师",
        "工艺工程师",
        "家用电器/数码产品研发",
        "仪器/仪表/计量分析师",
        "测试工程师",
        "安防系统工程师",
        "其他",
        "销售管理",
        "销售总监",
        "销售经理",
        "销售主管",
        "业务拓展主管/经理",
        "渠道/分销总监",
        "渠道/分销经理",
        "渠道/分销主管",
        "大客户管理",
        "客户经理/主管",
        "区域销售总监",
        "区域销售经理",
        "团购经理/主管",
        "其他",
        "销售人员",
        "大客户销售",
        "销售代表",
        "渠道/分销专员",
        "客户代表",
        "销售工程师",
        "电话销售",
        "网络/在线销售",
        "团购业务员",
        "经销商",
        "会籍顾问",
        "销售助理",
        "其他",
        "销售行政及商务",
        "销售行政经理/主管",
        "销售行政专员",
        "业务分析经理/主管",
        "业务分析专员/助理",
        "商务经理",
        "商务主管/专员",
        "商务助理",
        "销售行政助理",
        "其他",
        "客服及支持",
        "客服总监",
        "客服经理",
        "客服主管",
        "客服专员/助理",
        "客户关系经理/主管",
        "售前/售后技术支持经理",
        "售前/售后技术支持主管",
        "售前/售后技术支持工程师",
        "咨询热线/呼叫中心服务人员",
        "网络/在线客服",
        "投诉专员",
        "VIP专员",
        "其他",
        "财务/审计/税务",
        "首席财务官 CFO",
        "财务总监",
        "财务经理",
        "财务顾问",
        "财务主管/总账主管",
        "会计经理/会计主管",
        "会计",
        "出纳员",
        "财务助理/文员",
        "固定资产会计",
        "财务分析经理/主管",
        "财务分析员",
        "成本经理/成本主管",
        "成本管理员",
        "资金经理/主管",
        "资金专员",
        "审计经理/主管",
        "审计专员/助理",
        "税务经理/税务主管",
        "税务专员/助理",
        "统计员",
        "其他",
        "金融/证券/期货/投资",
        "证券/期货/外汇经纪人",
        "证券分析师",
        "股票/期货操盘手",
        "金融/经济研究员",
        "金融产品经理",
        "金融产品销售",
        "投资/基金项目经理",
        "投资/理财顾问",
        "投资银行业务",
        "投资银行财务分析",
        "融资经理/融资主管",
        "融资专员",
        "风险管理/控制",
        "拍卖/担保/典当业务",
        "其他",
        "银行",
        "行长/副行长",
        "银行客户总监",
        "个人业务部门经理/主管",
        "个人业务客户经理",
        "公司业务部门经理/主管",
        "公司业务客户经理",
        "综合业务经理/主管",
        "综合业务专员",
        "资产评估/分析",
        "风险控制",
        "信贷管理",
        "信审核查",
        "进出口/信用证结算",
        "外汇交易",
        "清算人员",
        "高级客户经理/客户经理",
        "客户主管/专员",
        "营业部大堂经理",
        "信用卡销售",
        "呼叫中心客服",
        "银行柜员",
        "其他",
        "保险",
        "保险精算师",
        "保险产品开发/项目策划",
        "保险业务经理/主管",
        "保险经纪人/保险代理",
        "理财顾问/财务规划师",
        "储备经理人",
        "保险电销",
        "保险核保",
        "保险理赔",
        "保险客户服务/续期管理",
        "保险培训师",
        "保险内勤",
        "契约管理",
        "其他",
        "生产/营运",
        "工厂经理/厂长",
        "总工程师/副总工程师",
        "项目总监",
        "项目经理/主管",
        "项目工程师",
        "营运经理",
        "营运主管",
        "生产总监",
        "生产经理/车间主任",
        "生产主管",
        "生产领班/组长",
        "生产计划/物料管理(PMC)",
        "生产文员",
        "设备主管",
        "化验员",
        "其他",
        "质量安全",
        "质量管理/测试经理(QA/QC经理)",
        "质量管理/测试主管(QA/QC主管)",
        "质量管理/测试工程师(QA/QC工程师)",
        "质量检验员/测试员",
        "可靠度工程师",
        "故障分析工程师",
        "认证工程师",
        "体系工程师",
        "审核员",
        "环境/健康/安全经理/主管（EHS）",
        "环境/健康/安全工程师（EHS）",
        "安全员",
        "供应商管理",
        "采购材料、设备质量管理",
        "其他",
        "工程/机械/能源",
        "技术研发经理/主管",
        "技术研发工程师",
        "产品工艺/制程工程师",
        "产品规划工程师",
        "项目管理",
        "实验室负责人/工程师",
        "工程/设备经理",
        "工程/设备主管",
        "工程/设备工程师",
        "工程/机械绘图员",
        "工业工程师",
        "材料工程师",
        "机械工程师",
        "结构工程师",
        "模具工程师",
        "机电工程师",
        "维修经理/主管",
        "维修工程师",
        "装配工程师/技师",
        "铸造/锻造工程师/技师",
        "注塑工程师/技师",
        "焊接工程师/技师",
        "夹具工程师/技师",
        "CNC工程师",
        "冲压工程师/技师",
        "锅炉工程师/技师",
        "电力工程师/技术员",
        "光源与照明工程",
        "光伏系统工程师",
        "汽车/摩托车工程师",
        "船舶工程师",
        "轨道交通工程师/技术员",
        "飞机维修机械师",
        "飞行器设计与制造",
        "水利/水电工程师",
        "空调/热能工程师",
        "石油天然气技术人员",
        "矿产勘探/地质勘测工程师",
        "其他",
        "汽车制造",
        "研发总监/部长/专家",
        "汽车机构工程师",
        "汽车设计工程师",
        "汽车电子工程师",
        "发动机/总装工程师",
        "动力总成工程师",
        "底盘工程师",
        "汽车项目管理",
        "汽车质量管理",
        "汽车安全性能工程师",
        "汽车装配工艺工程师",
        "电气/电器工程师",
        "附件系统工程师",
        "内外饰工程师",
        "车身/造型设计",
        "车辆质量工程师",
        "新能源电池工程师",
        "新能源电控工程师",
        "新能源电机工程师",
        "其他",
        "汽车销售与服务",
        "4S店经理/维修站经理",
        "汽车销售/经纪人",
        "汽车修理工",
        "汽车电工",
        "汽车钣金",
        "汽车喷漆",
        "汽车检验/检测",
        "汽车装饰美容",
        "洗车工",
        "售后服务/客户服务",
        "二手车评估师",
        "加油站工作员",
        "其他",
        "技工普工",
        "普工/操作工",
        "技工",
        "叉车/铲车工",
        "组装工",
        "包装工",
        "焊工",
        "氩弧焊工",
        "电工",
        "电力线路工",
        "旋压工",
        "仪表工",
        "电镀工",
        "喷塑工",
        "水工",
        "木工",
        "漆工",
        "空调工",
        "电梯工",
        "锅炉工",
        "学徒工",
        "其他",
        "服装/纺织/皮革",
        "服装/纺织设计总监",
        "服装/纺织设计",
        "服装/纺织/皮革工艺师",
        "面料辅料开发",
        "面料辅料采购",
        "服装/纺织/皮革跟单",
        "服装领班",
        "质量管理/验货员(QA/QC)",
        "板房/楦头/底格出格师",
        "电脑放码员",
        "纸样师/车板工",
        "裁床",
        "打样/制版",
        "裁剪工",
        "缝纫工",
        "手缝工",
        "烫工",
        "样衣工",
        "纺织工",
        "针织工",
        "配色工",
        "印染工",
        "漂染工",
        "挡车工",
        "整经工",
        "细纱工",
        "浆纱工",
        "其他",
        "采购",
        "采购总监",
        "采购经理",
        "采购主管",
        "采购员",
        "采购助理",
        "买手",
        "供应商开发",
        "其他",
        "贸易",
        "贸易/外贸经理/主管",
        "贸易/外贸专员/助理",
        "国内贸易人员",
        "业务跟单经理",
        "高级业务跟单",
        "业务跟单",
        "助理业务跟单",
        "其他",
        "物流/仓储",
        "物流总监",
        "物流经理",
        "物流主管",
        "物流专员/助理",
        "供应链总监",
        "供应链经理",
        "供应链主管/专员",
        "物料经理",
        "物料主管/专员",
        "仓库经理/主管",
        "仓库管理员",
        "订单处理员",
        "运输经理/主管",
        "项目经理/主管",
        "货运代理",
        "集装箱业务",
        "海关事务管理",
        "报关与报检",
        "单证员",
        "船务/空运陆运操作",
        "快递员",
        "调度员",
        "安检员",
        "理货员",
        "搬运工",
        "其他",
        "生物/制药/医疗器械",
        "生物工程/生物制药",
        "化学分析测试员",
        "医药技术研发管理人员",
        "医药技术研发人员",
        "医药学术推广",
        "临床研究员",
        "临床协调员",
        "临床数据分析员",
        "药品注册",
        "药品生产/质量管理",
        "药品市场推广经理",
        "药品市场推广主管/专员",
        "医药招商",
        "政府事务管理",
        "招投标管理",
        "医药销售经理/主管",
        "医药代表",
        "医药销售人员",
        "医疗器械注册",
        "医疗器械研发",
        "医疗器械生产/质量管理",
        "医疗器械市场推广",
        "医疗器械销售经理/主管",
        "医疗器械销售代表",
        "医疗器械维修人员",
        "其他",
        "化工",
        "化工技术应用/化工工程师",
        "化工实验室研究员/技术员",
        "涂料研发工程师",
        "配色技术员",
        "塑料工程师",
        "化妆品研发",
        "食品/饮料研发",
        "造纸研发",
        "其他",
        "医院/医疗/护理",
        "医院管理人员",
        "综合门诊/全科医生",
        "内科医生",
        "外科医生",
        "专科医生",
        "牙科医生",
        "美容整形师",
        "麻醉医生",
        "放射科医师",
        "理疗师",
        "中医科医生",
        "针灸/推拿",
        "儿科医生",
        "心理医生",
        "营养师",
        "药库主任/药剂师",
        "医药学检验",
        "公共卫生/疾病控制",
        "护理主任/护士长",
        "护士/护理人员",
        "兽医",
        "验光师",
        "其他",
        "广告",
        "广告客户总监/副总监",
        "广告客户经理",
        "广告客户主管/专员",
        "广告创意/设计经理",
        "广告创意总监",
        "广告创意/设计主管/专员",
        "广告制作执行",
        "美术指导",
        "文案/策划",
        "企业/业务发展经理",
        "企业策划人员",
        "其他",
        "公关/媒介",
        "公关总监",
        "公关经理",
        "公关主管",
        "公关专员",
        "会务/会展经理",
        "会务/会展主管",
        "会务/会展专员",
        "媒介经理",
        "媒介主管",
        "媒介专员",
        "公关/媒介助理",
        "媒介销售",
        "活动策划",
        "活动执行",
        "其他",
        "市场/营销",
        "市场/营销/拓展总监",
        "市场/营销/拓展经理",
        "市场/营销/拓展主管",
        "市场/营销/拓展专员",
        "市场助理",
        "市场分析/调研人员",
        "产品/品牌经理",
        "产品/品牌主管",
        "产品/品牌专员",
        "市场通路经理/主管",
        "市场通路专员",
        "市场企划经理/主管",
        "市场企划专员",
        "促销经理",
        "促销主管/督导",
        "促销员/导购",
        "选址拓展/新店开发",
        "其他",
        "影视/媒体",
        "影视策划/制作人员",
        "导演/编导",
        "艺术/设计总监",
        "艺术指导/舞台美术设计",
        "经纪人/星探",
        "主播/主持人",
        "摄影师/摄像师",
        "后期制作",
        "音效师",
        "配音员",
        "灯光师",
        "放映经理/主管",
        "放映员",
        "其他",
        "编辑出版",
        "总编/副总编",
        "编辑",
        "作家/撰稿人",
        "记者",
        "电话采编",
        "美术编辑",
        "排版设计",
        "出版/发行",
        "其他",
        "艺术/设计",
        "平面设计总监",
        "平面设计经理/主管",
        "平面设计师",
        "绘画",
        "动画/3D设计",
        "原画师",
        "展览/展示/店面设计",
        "多媒体设计",
        "包装设计",
        "工业/产品设计",
        "工艺品/珠宝设计鉴定",
        "家具/家居用品设计",
        "玩具设计",
        "其他",
        "建筑工程与装潢",
        "高级建筑工程师/总工",
        "建筑工程师",
        "建筑设计师",
        "市政工程师",
        "结构/土木/土建工程师",
        "公路/桥梁/港口/隧道工程",
        "岩土工程",
        "楼宇自动化",
        "建筑机电工程师",
        "智能大厦/综合布线/安防/弱电",
        "给排水/暖通工程",
        "幕墙工程师",
        "规划与设计",
        "室内设计",
        "园艺/园林/景观设计",
        "测绘/测量",
        "建筑制图/模型/渲染",
        "开发报建",
        "工程造价师/预结算经理",
        "预结算员",
        "建筑工程管理/项目经理",
        "建筑项目助理",
        "建筑工程验收",
        "工程监理",
        "合同管理",
        "安全员",
        "资料员",
        "建筑安装施工员",
        "砌筑工",
        "瓦工",
        "混凝土工",
        "浇注工",
        "钢筋工",
        "木工",
        "油漆工",
        "电梯工",
        "抹灰工",
        "施工开料工",
        "管道/暖通",
        "工长",
        "其他",
        "房地产开发",
        "房地产项目/策划经理",
        "房地产项目/策划主管/专员",
        "房地产投资管理",
        "房产项目配套工程师",
        "房地产项目招投标",
        "房地产投资分析",
        "房地产资产管理",
        "监察人员",
        "其他",
        "房地产销售与中介",
        "房地产销售经理/主管",
        "房地产销售",
        "房地产中介/置业顾问",
        "房地产评估",
        "房地产店长/经理",
        "房地产内勤",
        "房地产客服",
        "其他",
        "物业管理",
        "物业管理经理",
        "物业管理主管",
        "物业管理专员/助理",
        "前介工程师",
        "物业设施管理人员",
        "物业机电维修工",
        "物业维修员",
        "高级物业顾问/物业顾问",
        "物业招商/租赁/租售",
        "停车管理员",
        "保安经理",
        "保安人员",
        "物业机电工程师",
        "保洁",
        "绿化工",
        "其他",
        "人力资源",
        "人事总监",
        "人事经理",
        "人事主管",
        "人事专员",
        "人事助理",
        "招聘经理/主管",
        "招聘专员/助理",
        "薪资福利经理/主管",
        "薪资福利专员/助理",
        "绩效考核经理/主管",
        "绩效考核专员/助理",
        "培训经理/主管",
        "培训专员/助理/培训师",
        "企业文化/员工关系/工会管理",
        "人力资源信息系统专员",
        "其他",
        "高级管理",
        "首席执行官CEO/总裁/总经理",
        "首席运营官COO",
        "副总经理/副总裁",
        "合伙人",
        "总监/部门经理",
        "策略发展总监",
        "企业秘书/董事会秘书",
        "投资者关系",
        "办事处首席代表",
        "办事处/分公司/分支机构经理",
        "总裁助理/总经理助理",
        "其他",
        "行政/后勤",
        "行政总监",
        "行政经理/主管/办公室主任",
        "行政专员/助理",
        "经理助理/秘书",
        "党工团干事",
        "前台接待/总机/接待生",
        "图书管理员/资料管理员",
        "电脑操作员/打字员",
        "后勤",
        "其他",
        "咨询/顾问",
        "专业顾问",
        "咨询总监",
        "咨询经理",
        "专业培训师",
        "咨询员",
        "调研员",
        "猎头/人才中介",
        "情报信息分析人员",
        "其他",
        "律师/法务/合规",
        "律师/法律顾问",
        "律师助理",
        "法务经理",
        "法务主管/专员",
        "法务助理",
        "合规经理",
        "合规主管/专员",
        "知识产权/专利/商标",
        "其他",
        "教师",
        "校长",
        "大学教授",
        "讲师/助教",
        "中学教师",
        "小学教师",
        "幼教",
        "外语培训师",
        "院校教务管理人员",
        "兼职教师",
        "家教",
        "音乐/美术教师",
        "体育教师",
        "职业技术教师",
        "其他",
        "培训",
        "培训督导",
        "培训讲师",
        "培训策划",
        "培训产品开发",
        "培训/课程顾问",
        "培训助理",
        "其他",
        "科研",
        "科研管理人员",
        "科研人员",
        "餐饮服务",
        "店长/经理",
        "大堂经理",
        "餐厅领班",
        "餐饮服务员",
        "行政主厨/厨师长",
        "中餐厨师",
        "西餐厨师",
        "日式厨师",
        "面点师",
        "西点师",
        "厨师助理/学徒",
        "茶艺师",
        "咖啡师",
        "调酒师/侍酒师/吧台员",
        "礼仪/迎宾",
        "预订员",
        "收银员",
        "配菜/打荷",
        "传菜主管",
        "传菜员",
        "洗碗工",
        "送餐员",
        "杂工",
        "其他",
        "酒店旅游",
        "酒店/宾馆经理",
        "酒店/宾馆销售",
        "预定部主管",
        "预定员",
        "大堂经理",
        "酒店前台",
        "宴会管理",
        "宾客服务经理",
        "楼面经理",
        "客房服务员/楼面服务员",
        "健身房服务",
        "行李员",
        "管家部经理/主管",
        "清洁服务人员",
        "旅游产品销售",
        "行程管理/计调",
        "签证专员",
        "导游/旅行顾问",
        "票务",
        "机场代表",
        "其他",
        "美容保健",
        "美容店长",
        "美容培训师/导师",
        "美容顾问",
        "美容师",
        "美容助理",
        "彩妆培训师",
        "专柜彩妆顾问(BA)",
        "化妆师",
        "造型师",
        "美发店长",
        "发型师",
        "发型助理/学徒",
        "美甲师",
        "美体师",
        "瘦身顾问",
        "SPA 技师",
        "按摩",
        "足疗",
        "宠物护理/美容",
        "其他",
        "百货零售",
        "卖场经理/店长",
        "品类经理",
        "品牌/连锁招商管理",
        "奢侈品业务",
        "店员/营业员",
        "珠宝销售顾问",
        "督导/巡店",
        "导购员",
        "促销员",
        "收银主管",
        "收银员",
        "陈列员",
        "收货员",
        "理货员",
        "安防主管",
        "防损员/内保",
        "西点师/面包糕点加工",
        "生鲜食品加工/处理",
        "熟食加工",
        "兼职店员",
        "其他",
        "交通运输服务",
        "飞机机长/副机长",
        "空乘人员",
        "列车/地铁车长",
        "船长/副船长",
        "商务司机",
        "客运司机",
        "货运司机",
        "出租车司机",
        "班车司机",
        "列车/地铁司机",
        "特种车司机",
        "叉车司机",
        "铲车司机",
        "吊车司机",
        "驾校教练",
        "代驾",
        "地勤人员",
        "乘务员",
        "船员",
        "其他",
        "家政保洁",
        "家政服务/保姆",
        "月嫂",
        "育婴师/保育员",
        "护工",
        "清洁工",
        "钟点工",
        "洗衣工",
        "送水工",
        "保镖",
        "空调维修",
        "家电维修",
        "寻呼员/话务员",
        "其他",
        "公务员",
        "公务员",
        "翻译",
        "英语翻译",
        "日语翻译",
        "德语翻译",
        "法语翻译",
        "俄语翻译",
        "意大利语翻译",
        "西班牙语翻译",
        "葡萄牙语翻译",
        "阿拉伯语翻译",
        "韩语/朝鲜语翻译",
        "泰语翻译",
        "中国方言翻译",
        "其他语种翻译",
        "在校学生",
        "研究生",
        "大学/大专应届毕业生",
        "中专/职校生",
        "其他",
        "储备干部/培训生/实习生",
        "储备干部",
        "培训生",
        "实习生",
        "兼职",
        "兼职",
        "环保",
        "环保工程师",
        "环境影响评价工程师",
        "生态治理/规划",
        "环保检测",
        "水质检测员",
        "水处理工程师",
        "固废工程师",
        "废气处理工程师",
        "其它",
        "农/林/牧/渔",
        "养殖部主管",
        "场长(农/林/牧/渔业)",
        "农艺师",
        "畜牧师",
        "饲养员",
        "农业技术员",
        "动物营养/饲料研发",
        "其他",
        "网店淘宝",
        "网店/淘宝店长",
        "网店/淘宝运营",
        "网店店铺管理员",
        "网店/淘宝客服",
        "店铺推广",
        "网店美工",
        "网店模特",
        "其他",
        "机械机床",
        "数控操机",
        "数控编程",
        "机修工",
        "折弯工",
        "车工",
        "磨工",
        "铣工",
        "冲压工",
        "刨工",
        "钳工",
        "钻工",
        "镗工",
        "铆工",
        "钣金工",
        "抛光工",
        "切割技工",
        "模具工",
        "炼胶工",
        "硫化工",
        "吹膜工",
        "注塑工",
        "其他",
        "印刷包装",
        "印刷工",
        "校对/录入",
        "调色员",
        "烫金工",
        "晒版员",
        "印刷排版/制版",
        "装订工",
        "印刷机械机长",
        "数码直印/菲林输出",
        "调墨技师",
        "电分操作员",
        "打稿机操作员",
        "切纸机操作工",
        "裱胶工",
        "压痕工",
        "复卷工",
        "其他",
        "运动健身",
        "健身顾问/教练",
        "瑜伽老师",
        "舞蹈老师",
        "游泳教练",
        "救生员",
        "高尔夫教练",
        "体育运动教练",
        "其他",
        "休闲娱乐",
        "司仪",
        "婚礼/庆典策划服务",
        "DJ",
        "驻唱/歌手",
        "舞蹈演员",
        "模特",
        "演员/群众演员",
        "娱乐领班",
        "娱乐服务员",
        "前台迎宾",
        "其他",
        "其他",
        "驯兽师/助理驯兽师",
        "志愿者/社会工作者",
        "其他",
    ]
